@@ -32,7 +32,7 @@ def url_to_array(url):
     result = requests.get(url, timeout=3)
     if result.ok:
         img = Image.open(io.BytesIO(result.content))
-        img =  img.convert('RGB')
+        img =  img.convert('RGBA')
         data =  np.array(img)
         return data
     else:
